package ballwar.model;

import util.*;
import java.util.*;

public class CollisionCmd implements IBallCmd {
  public static final CollisionCmd Singleton = new CollisionCmd();
  private CollisionCmd() {}
  
  private HashSet alreadyChecked = new HashSet();
  
  public void reset() {
    alreadyChecked.clear();
  }
  
  public void apply(final Ball context) {
    alreadyChecked.add(context);
    context.getEnv().getDispatcher().notifyAll( new IBallCmd() {
      public void apply(Ball otherBall){
        if(!alreadyChecked.contains(otherBall)){
          double distance = context.getLocation().distance(otherBall.getLocation());
          double minSeparation = context.getRadius() + otherBall.getRadius(); 
          if( minSeparation > distance) {
            // normal direction
            double nx = ((double)(context.getLocation().x - otherBall.getLocation().x))/distance;
            double ny = ((double)(context.getLocation().y - otherBall.getLocation().y))/distance;
            // delta velocity in normal direction  (va-vb).n
            double dvn = (context.getVelocity().x - otherBall.getVelocity().x)*nx + (context.getVelocity().y - otherBall.getVelocity().y)*ny; 
            if(dvn<0.0) {   // Only collide if going towards each other
              double mass = context.getMass();
              // Reduced mass = (m1*m2)/(m1+m2)
              double mr;
              if(mass == Double.POSITIVE_INFINITY) mr = otherBall.getMass();
              else mr = mass/(1.0+(mass/otherBall.getMass()));
              double impx = 2.0*mr*dvn*nx;
              double impy = 2.0*mr*dvn*ny;
              context.getVelocity().translate(-impx/mass, -impy/mass);
              context.getStrategy().updateCollision(context, otherBall);
              otherBall.getVelocity().translate(impx/otherBall.getMass(), impy/otherBall.getMass());
              otherBall.getStrategy().updateCollision(otherBall, context);              
            }
          }          
        }
      }
    });    
  }
}