
package ballwar.model;

/**
 * Interface that represents a set of movement keys.   
 * Key names are the virtual key names without the leading "VK_".   
 * See the Java documentation under "KeyEvent".
 */
public abstract interface IMovementKeys {
  /**
	 * A predefined set of movement keys where the arrow keys ("UP", "DOWN", "LEFT" and "RIGHT") are associated
	 * with their respective directions and the "END" key is associated with stopping.
	 */
	public final static IMovementKeys ARROWSEND = new IMovementKeys() {
    public String getUpKey() { return "UP"; }
    public String getDownKey() { return "DOWN"; }
    public String getLeftKey() { return "LEFT"; }
    public String getRightKey() { return "RIGHT"; }
    public String getStopKey() { return "END"; }
    public String toString() {
      return "Arrows+End";
    }
  };

  /**
	 * A predefined set of movement keys where "W" = up, "A" = left, "S" = stop, "D" = right, and "X"=down.
	 */
	public final static IMovementKeys WASDX = new IMovementKeys() {
    public String getUpKey() { return "W"; }
    public String getDownKey() { return "X"; }
    public String getLeftKey() { return "A"; }
    public String getRightKey() { return "D"; }
    public String getStopKey() { return "S"; }
    public String toString() {
      return "WASDX";
    }    
  };
  
  /**
	 * Get the name of the key that controls upward movement.
	 * @return The name of the virtual key minus the "VK_".
	 */
	public abstract String getUpKey();
  
  /**
	 * Get the name of the key that controls downward movement.
	 * @return The name of the virtual key minus the "VK_".
	 */
	public abstract String getDownKey();
  
  /**
	 * Get the name of the key that controls leftward movement.
	 * @return The name of the virtual key minus the "VK_".
	 */
	public abstract String getLeftKey();
  
  /**
	 * Get the name of the key that controls right ward movement.
	 * @return The name of the virtual key minus the "VK_".
	 */
	public abstract String getRightKey();
  
  /**
	 * Get the name of the key that stops the movement.
	 * @return The name of the virtual key minus the "VK_".
	 */
	public abstract String getStopKey();
}

