package ballwar.model;

import java.awt.*;
import java.awt.geom.*;

/**
 * Interface that represents a strategy used by a Ball when asked to perform variant paint operations.
 * 
 */
public interface IPaintStrategy {
  
  /**
   * Paints the host onto the given Graphics context. 
   * The image is translated, scaled and rotated as determined
   * by the host's locaton, radius, and velocity
   * @param g The graphics context to draw upon.
   * @param host The host ball.
   */
  public void paint(Graphics g, Ball host);
    
  /**
   * Paints the host onto the given Graphics context. 
   * The image is translated, scaled and rotated as determined
   * by the given affine transformation.   
   * This allows the same transformation to be shared amongst multiple
   * paint strategies.
   * @param g The graphics context to draw upon.
   * @param host The host ball.
   * @param at The affine transform to use.
   */
  public void paintXfrm(Graphics g, Ball host, AffineTransform at);
  
  /**
  * Initializes the given ball.   Called once by the ball when the strategy is first loaded.
  * @param host The ball to initialize.
  */
 public void init(Ball host);
  
  /**
   * The singleton null object instance for this interface, which does nothing.
   */
  public static final IPaintStrategy NullObject = new IPaintStrategy() {
    public void paint(Graphics g, Ball host) {}
    public void paintXfrm(Graphics g, Ball host, AffineTransform at) {}
    public void init(Ball context){};
  };
}