
package ballwar.model;

/**
 * Interface that represents a single player that has a name and a score and is associated wtih a particular set of movement keys.
 */
public abstract interface IPlayer {
  
  /**
   * Null object IPlayer singleton instance that does nothing.
   * Score = 0 always, Name = "", movement keys = null always.
   */
  public static final IPlayer NullPlayer = new IPlayer() { 
    public int getScore() { return 0; }
    public void setScore(int score) {}
    public String getName() {return "";}
    public IMovementKeys getMovementKeys() {return null;}
    public void setMovementKeys(IMovementKeys keys) {}
  };
  
  /**
  * Get the player's score
  * @return The player's score.
  */
 public abstract int getScore();
  /**
  * Sets the player's score (integer value).
  * @param score The new score.
  */
 public abstract void setScore(int score);
  /**
  * Get the player's name.
  * @return The player's name.
  */
 public abstract String getName();
  /**
  * Get the set of movement keys associated with this player.
  * @return The IMovement keys object for this player.
  */
 public abstract IMovementKeys getMovementKeys();
  /**
  * Set the set of movement keys to be associated with this player.
  * @param keys The new IMovementKeys object for this player.
  */
 public abstract void setMovementKeys(IMovementKeys keys);
}

