package ballwar.model;

import javax.swing.*;

/**
 * An abstract factory used for manufacturing strategies.  The controller subclasses this using 
 * anonymous inner classes to produce custom factories at run time.
 */
public interface IStrategyFac { 
  /**
   * Instantiate an IUpdateStrategy
   * @return An IUpdateStrategy instance.
   */
  public IUpdateStrategy make();
  
  public JPanel getConfigPanel(final AbstractButton acceptBtn, final AbstractButton cancelBtn);
  
  public static final IStrategyFac NullObject = new IStrategyFac() {
    public IUpdateStrategy make() {
      return IUpdateStrategy.NullObject;
    }
    
    public JPanel getConfigPanel(AbstractButton acceptBtn, AbstractButton cancelBtn) {
      return new JPanel() {
        {
          add(new JLabel("No configuration available"));
        }
        public String toString() {
          return "IUpdateStrategy.NullObject configuration";
        }
      };
    }
    
    public String toString() {
      return "IStrategyFac.NullObject";
    }
  };
}