package ballwar.model;
import util.*;
import java.awt.*;


/**
 * The adapter interface the model uses to communicate to the view.  
 */
public interface IViewCtrlAdapter {
  /**
  * Method that is called when the model wishes the view to update.    
  * Periodicaly called by the model's timer.    
  * The view will then turn around and call the model's paint method when it 
  * needs the model to update and paint.  
  */
 public abstract void update();
 
 public abstract Component getComponent();
  /**
  * Gets the width of the GUI component upon which the balls are painted.
  * @return The width of the ball's display area in pixels.
  */
 public abstract int getCanvasWidth();
  /**
  * Gets the height of the GUI component upon which the balls are painted.
  * @return The height of the ball's display area in pixels.
  */
 public abstract int getCanvasHeight();
  /**
  * Asks the GUI to associate the given key with the given behavior.  
  * @param keyName The name of the virtual key, less the leading "VK_".   See the Java documentation for "KeyEvent"
  * @param cmd The behavior to be associated with the key.   The ILambda's apply() method will be called with the key's name when that key is pressed.
  */
 public abstract void addKeyCmd(String keyName, ILambda cmd);
  /**
  * Returns the currently selected player on the GUI.
  * @return The currently selected player.
  */
 public abstract IPlayer getSelectedPlayer();
}
  
