package ballwar.model.paint;

import util.*;
import ballwar.model.*;
import java.awt.*;
import javax.swing.*;
import java.awt.geom.*;
import java.awt.image.*;

/**
 * An example of an ImagePaintStrategy that randomly picks one
 * of two animated image files to display when it is instantiated. 
 */
public class BirdSheepImagePaintStrategy extends ImagePaintStrategy {
  /**
   * No-parameter constructor that instantiates the AffineTransform used
   * internally and randomly loads one of two files: 
   * ballwar\model\paint\images\humbird4.gif or
   * ballwar\model\paint\images\img104c.gif with a fill factor of 0.5.
   */
  public BirdSheepImagePaintStrategy() {
    super(Math.random()>.5? "images/humbird4.gif":"images/img104c.gif", 0.5);
  }

  /**
   * Augments the inhereited paint method to add
   * flipping of the image to keep it upright.
   */
  protected void paintCfg(Graphics g, Ball host) {
    super.paintCfg(g, host);
    if(Math.abs(Math.abs(Math.atan2(host.getVelocity().y, host.getVelocity().x)))> Math.PI/2.0) {
      at.scale(1.0, -1);
    }        
  }
  
}