package ballwar.model.paint;
import java.awt.*;
import java.awt.geom.*;

/**
 * Concrete shape factory that instantiates Ellipse2D.Double shapes.
 */
public class EllipseShapeFactory implements IShapeFactory {
  /**
   * Singleton pattern
   */
  public static final EllipseShapeFactory Singleton = new EllipseShapeFactory();
  private EllipseShapeFactory() {}
  
  /**
   * Instantiates an ellipse
   * @param x x-coordinate of the center of the ellipse
   * @param y y-coordinate of the center of the ellipse
   * @param xScale The x-radius of the ellipse
   * @param yScale The y-radius of the ellipse
   * @return An Ellipse2D.Double object.
   */
  public Shape makeShape(double x, double y, double xScale, double yScale) {
    return new Ellipse2D.Double(x-xScale, y-yScale, 2*xScale, 2*yScale);
  }
}