package ballwar.model.paint;

import ballwar.model.*;
import java.awt.*;
import java.awt.geom.*;

/**
 * Subclass of MultiPaintStrategy that uses a SwimFishPaintStrategy and an 
 * EllipsePaintStrategy to paint a swimming fish shape that 
 * has an eye.
 */
 public class NiceFishPaintStrategy extends MultiPaintStrategy {
  
  /**
   * No-parameter constructor that instantiates the AffineTransform for internal use.
   */
  public NiceFishPaintStrategy(){
    this(new AffineTransform());
  }
  
  /**
   * Constructor that uses an externally supplied AFfineTransform for 
   * internal use.
   * @param at The AffineTransform to use.
   */
  public NiceFishPaintStrategy(AffineTransform at){
    super(at, new SwimFishPaintStrategy(at), 
          new FixedColorDecoratorPaintStrategy(Color.BLACK, 
                                               new EllipsePaintStrategy(at, .6, -.15, .1, .1)));
  }

   
  /**
   * Override paintCfg to add the transform needed to 
   * keep the fish upright at all times.
   */
  protected void paintCfg(Graphics g, Ball host) {
   if(Math.abs(Math.abs(Math.atan2(host.getVelocity().y, host.getVelocity().x)))> Math.PI/2.0) {
      at.scale(1, -1);
    }        
  }
  
}