package ballwar.model.paint;

import ballwar.model.*;
import java.awt.*;
import java.awt.geom.*;

/**
 * Concrete class that defines invariant painting behaviors for all
 * Shape subclasses. 
 * Note: This cannot be directly instantiated by the BallWar system 
 * because it does not have a no-parameter constructor. 
 */
public class ShapePaintStrategy extends APaintStrategy {
  
  /**
   * The Shape to be painted
   */
  private Shape shape;
  
  /**
   * Constructor that allocates a new AffineTransform for internal use.
   * @param shape  The Shape to be painted.
   */
  public ShapePaintStrategy(Shape shape){
    this(new AffineTransform(), shape);
  }
    
  /**
   * Constructor that uses a supplied AffineTransform for internal use.
   * @param at The AffineTransform to use
   * @param shape  The Shape to be painted.
   */
  public ShapePaintStrategy(AffineTransform at, Shape shape){
    super(at);
    this.shape = shape;
  }
  
  /**
   * Paints the shape on the given Graphics context using the 
   * supplied AffineTransform. Called by the inherited paint method.
   * @param g The Graphics context to paint upon.
   * @param host The host Ball
   * @param at The AffineTransform to use
   */
  public void paintXfrm(Graphics g, Ball host, AffineTransform at){ 
    ((Graphics2D) g).fill(at.createTransformedShape(shape));
  }
}