package ballwar.model.strategy;
import util.*;
import ballwar.model.*;

/**
 * An ANoOpStrategy-based strategy that only only overrides the updateState behavior 
 * to make the ball's radius grower larger and smaller in a random sinusoidal manner.
 */
public class BreathingStrategy extends ANoOpStrategy {
  /**
	 * The minimum possible value for the minumum radius of a ball.
	 */
	private static int _MinRadiusLowerLimit = 1;
  /**
	 * The maximum possible  value for a ball's minimum radius.
	 */
	private static int _MinRadiusUpperLimit = 15;
  /**
	 * The minimum possible value for the maximum radius of a ball.
	 */
	private static int _MaxRadiusLowerLimit = 5;
  /**
	 * The maximum possible value for the maximum radius of a ball.
	 */
	private static int _MaxRadiusUpperLimit = 20;
  /**
	 * The minumum possible value for the angle increment of the sinusoid between updateState calls, in radians.
	 */
	private static double _DeltaLowerLimit = .01;
  /**
	 * The maximum possible value for the angle increment of the sinusoid between updateState calls, in radians.
	 */
	private static double _DeltaUpperLimit = .01;
  
  /**
	 * The Randomizer used to create the random values.
	 */
	private IRandomizer rand = Randomizer.Singleton;
  
  /**
	 * A SineMaker object that creates a sinusoidally varying value.
	 */
	private SineMaker sm = new SineMaker(rand.randomInt(_MinRadiusLowerLimit,_MinRadiusUpperLimit),
                                       rand.randomInt(_MaxRadiusLowerLimit,_MaxRadiusUpperLimit),
                                       rand.randomDouble(_DeltaLowerLimit,_DeltaUpperLimit));
   
  /**
	 * Sets the ball's radius to the current value returned by the SineMaker object.
	 * @param context The ball who's radius is to be modified.
	 */
	public void updateState(Ball context) {
    context.setRadius(sm.getIntVal());
  }
}
