package ballwar.model.strategy;
import java.awt.*;

import ballwar.model.*;
import util.*;

/**
 * ANoOpStrategy-based strategy that continuously modifies the velocity to produce circular motion.
 */
public class CurveStrategy extends ANoOpStrategy {
  /**
  * Randomizer used to randomly generate the increment angle.
  */
 private IRandomizer rand = Randomizer.Singleton;
  
  /**
  * The incremental amount to rotate the context's velocity by each time its updateState is called (in radians).
  */
 private double angle = rand.randomDouble(-Math.PI/4.0, Math.PI/4.0);
  /**
  * Precalculated value of cos(angle)
  */
 //private double cosA = Math.cos(angle);
  /**
  * Pre-calculated value of sin(angle)
  */
 //private double sinA = Math.sin(angle);
  
  
  /**
  * Rotates the context's velocity by the specified angle.
  * @param context The strategy's context
  */
 public void updateState(Ball context) {
    final Point2DDouble v = context.getVelocity();
    double deltaTime = context.getEnv().getDeltaTime();
    double cosA = Math.cos(angle*deltaTime);
    double sinA = Math.sin(angle*deltaTime);
    final double x =cosA*v.getX()+ sinA*v.getY();
    final double y = cosA*v.getY()-sinA*v.getX();
    context.addUpdateCmd(new IBallCmd() {
      public void apply(Ball host) {
        v.setLocation(x, y);
      }
    });
  }
}
