package ballwar.model.strategy;
import java.awt.*;

import ballwar.model.*;
import util.*;

/**
 * AUpdateStrategy-bsed strategy that delegates to one of 4 randomly choosen strategies whenever it's updateState is called. 
 */
public class DrunkenStrategy extends AUpdateStrategy {
  
  /**
	 * A possible strategy to use.  Defaults to a StraightStrategy.
	 */
	private IUpdateStrategy s1 = new StraightStrategy();
  /**
	 * A possible strategy to use.  Defaults to a CurveStrategy.
	 */
	private IUpdateStrategy s2 = new CurveStrategy();
  /**
	 * A possible strategy to use.  Defaults to a BreathingStrategy.
	 */
	private IUpdateStrategy s3 = new BreathingStrategy();
  /**
	 * A possible strategy to use.  Defaults to a ColorStrategy.
	 */
	private IUpdateStrategy s4 = new ColorStrategy();
  
  /**
	 * Randomizer used to generate the random values.
	 */
	private IRandomizer rand = Randomizer.Singleton;
  
  /**
	 * Randomly delegates to one of the four stored strategies as per the following probabilities:
	 *  s1: 0.64, s2: 0.16,  s3: 0.10 and s4: 0.10
	 * @param context The strategy's context
	 */
	public void updateState(Ball context) {
    ((IUpdateStrategy) rand.randomChoice(rand.randomChoice(s1,s2, .8),
                                         rand.randomChoice(s3, s4,.5),
                                         0.8)).updateState(context);
  }
}

