package ballwar.model.strategy;
import java.awt.*;
import util.*;

import ballwar.model.*;

/**
 * An ANoOpStrategy-based strategy that, upon colliding with another ball, may replace its context
 *  with a number of smaller balls with the same strategy, unless the context's radius is below 
 * a minumum length, upon which the context is simply killed.    The size and masses of the new balls 
 * are calculated to conservere total area and mass before and after the collision..
 */
public class ExplodeStrategy extends ANoOpStrategy {
  
  /**
  * The probability of explosion.
  */
 private static double _Prob = .1; 
  /**
  * The minimum radius that will explode.   smaller radius
  * will simply kill its context ball.
  */
 private static int _MinRadius = 9;
  /**
  * The number of balls to explode into.
  */
 private static int _NBalls = 9;
  /**
  * The divisor of the radius when the ball explodes.   
  * Equals the square root of the number of balls in 
  * order to conserve area and hence, mass.
  */
 private static int _RadiusDivider = (int)Math.sqrt(_NBalls);
 
 private static double theta = 2.0*Math.PI/_NBalls;
  
  /**
  * With a given probability, explodes the context ball into a number of smaller balls, 
  * unless the context's radius is below a minimum length, upon which the 
  * context is killed and no more balls are made.
  * @param context The strategy's context 
  * @param target The ball the context collided with.
  */
 public void updateCollision(Ball context, Ball target) {
    if(_Prob > Math.random()) {
      if(_MinRadius > context.getRadius()) {}//context.kill();
      else {   // make new, smaller balls.
        IBallEnvironment env = context.getEnv();
        int newRadius = context.getRadius()/_RadiusDivider;
        // radius of circle of new balls
        double r = newRadius/Math.sin(Math.PI/_NBalls);
        double newMass = context.getMass()/_NBalls;
        Point2DDouble loc = context.getLocation();
        for(int i=0; i<_NBalls; i++) {
          Ball b = new Ball(env, context.getStrategy(), context.getPaintStrategy());
          // Arrange the new balls in a ring around the old location.
          double x = loc.x+r*Math.cos(i*theta);
          double y = loc.y+r*Math.sin(i*theta);
          
//          b.setLocation(new Point2DDouble(context.getLocation()));
          b.setLocation(new Point2DDouble(x, y));
          b.setRadius(newRadius);
          b.setMass(newMass);
          b.setVelocity(new Point2DDouble(context.getVelocity()));
          env.getDispatcher().addObserver(b);
        }
        context.kill();  // kill the original ball.
      }
    }
  }
}