package ballwar.model.strategy;
import java.awt.*;
import ballwar.model.*;

/**
 * An ANoOpStrategy-based strategy that switches its color to a preset "lit up" color for a while after a collision.
 */
public class LightUpStrategy extends ANoOpStrategy {
  /**
	 * The number of update cycles to remain "lit up".
	 */
	private static int _LitUpDuration = 10;
  /**
	 * The color when "lit up"
	 */
	private static Color _LitUpColor = Color.RED;
  /**
	 * The count of how many cycles have passed since initially being lit up.
	 */
	private int _count = 0;
  /**
	 * The pre-lit-up color.
	 */
	private Color _oldColor = Color.BLACK;
  
  /**
	 * Updates the state of the context.  If the count is not positive, set the color of the context 
	 * back to what it was before the collision.
	 * @param context The stategy's context.
	 */
	public void updateState(Ball context) {
    if(0<_count) { // process if positive value for count
      // decrement count first, then check if it is zero.
      // restore old color if count has reached zero
      if(0== --_count) context.setColor(_oldColor);
    }
  }  
  
  /**
	 * I the count is non-positive, saves the color of the context, sets the count to a preset value and 
	 * sets the color of the context to a preset "lit up" value.
	 * @param context The strategy's context.
	 * @param target The target ball that the context hit.
	 */
	public void updateCollision(Ball context, Ball target) {
    if(0>=_count) _oldColor = context.getColor(); // If not lit up, save old color.
    _count = _LitUpDuration; // Stay lit up for 10 updates.
    context.setColor(_LitUpColor);  // Switch to lit up color
  }
  
  /**
	 * Saves the context's current color.
	 * @param context The context of the strategy
	 */
	public void init(final Ball context) {
    _oldColor = context.getColor(); // save original color.
  }  
}
