package ballwar.model.strategy;
import java.awt.*;
import ballwar.model.*;
import util.*;

/**
 * An ANoOpStrategy-based strategy that modifies the velocity of the context ball through user key presses.
 */
public class MoveStrategy extends ANoOpStrategy {
  /**
   * The amount the ball's velocity is changed in the requested 
   * direction each time a key press is registered.
   */
  private int _delta = 1;
  
  /**
  * If the increment value (delta) is greater than 1, decrement the increment value.   
  * This will slowly return the sensitivity of the keyboard control back to its beginning value (1).
  * @param context This strategy's context.
  */
 public void updateState(Ball context) {
    if(1<_delta) _delta--;
  }
  
  /**
  * Initializes the context such that the movement keys of  the currently selected 
  * player are registered with the environment.   The movement keys will increment 
  * the velocity in the appropriate direction by the set amount (delta) when the respective
  * key is pressed.  The stop key will cause the velocity to become zero.   Every time 
  * a key is pressed, the velocity increment is incremented.    This causes the keys to 
  * appear to become more sensitivee the longer and more often the keys are pressed. 
  * @param context This strategy's context.
  */
 public void init(final Ball context) {    
    IBallEnvironment env = context.getEnv();
    
    IPlayer player = env.getSelectedPlayer();
    
    env.registerMovementKeys(player.getMovementKeys(), new IMoveable() {
      public Point2DDouble getLocation() {
        return context.getLocation();
      }
      public void moveLeft(){
        context.getVelocity().translate(-_delta,0);
        _delta += 1; 
      }
      public void moveRight(){
        context.getVelocity().translate(_delta, 0);
        _delta += 1; 
      }
      public void moveUp(){
        context.getVelocity().translate(0, -_delta);
        _delta += 1; 
      }
      public void moveDown(){
        context.getVelocity().translate(0, _delta);
        _delta += 1; 
      }
      public void stop(){
        context.setVelocity(new Point2DDouble(0,0));
        _delta = 1; 
      }
    });    
  }
}
