package ballwar.model.strategy;
import ballwar.model.*;
import java.awt.*;
import java.awt.geom.*;
import util.*;
import lrs.*;

/**
 * A wall consisting of multiple one-sided walls.
 */
public class MultiSideWallStrategy extends ANoOpStrategy {
  /**
   * The set of one-sided walls
   */
  private LRStruct wallSet = new LRStruct();
  
  /**
   * Algo to update all the walls.
   */
  private IAlgo updateAlgo = new IAlgo() {
    public Object emptyCase(LRStruct host, Object...context) {
      return null;
    }
    public Object nonEmptyCase(LRStruct host, Object...context) {
      ((OneSideWallStrategy)host.getFirst()).updateState((Ball) context[0]);
      return host.getRest().execute(this, context);
    }
  };
  
  /**
   * Paint strategy that is forced into the host ball that is the composite of
   * all the paintstrategies from the one-sided walls.
   */
  private IPaintStrategy paintStrategy = new IPaintStrategy() {
      public void paint(Graphics g, Ball host) {
        wallSet.execute(paintAlgo, g, host);
      }
  
      public void paintXfrm(Graphics g, Ball host, AffineTransform at) {}
  
      public void init(Ball host) {}
    };  

  /**
   * Algo to paint all the walls.
   */
  private IAlgo paintAlgo = new IAlgo() {
    public Object emptyCase(LRStruct host, Object...inp) {
      return null;
    }
    public Object nonEmptyCase(LRStruct host, Object...inp) {
      ((OneSideWallStrategy)host.getFirst()).getPaintStrategy().paint((Graphics) inp[0], (Ball) inp[1]); 
      return host.getRest().execute(this, inp);
    }
  };

  /**
   * Algo to initialize all the walls
   */
  private IAlgo initAlgo = new IAlgo() {
    public Object emptyCase(LRStruct host, Object...context) {
      return null;
    }
    public Object nonEmptyCase(LRStruct host, Object...context) {
      ((OneSideWallStrategy)host.getFirst()).init((Ball) context[0]); 
      return host.getRest().execute(this, context);
    }
  };

  public MultiSideWallStrategy(OneSideWallStrategy... walls) {
    for(OneSideWallStrategy aWall : walls) {
      wallSet.insertFront(aWall);
    }
  }
  
  /**
   * Creates a random rectangular box of walls
   * either with walls facing outward or inward.
   */
  public MultiSideWallStrategy() {
    Color wallColor = Color.BLUE;
    double x0 =  700*Math.random();
    double y0 =  700*Math.random();
    
    double sx =  500*(Math.random()-0.5);
    double sy =  500*(Math.random()-0.5);
    
    double width = 700*(Math.random()-0.5);
    double s = Math.sqrt(sx*sx+sy*sy);
                  
    double wx = -width*sy/s;             
    double wy = width*sx/s;
                    
                    
    wallSet.insertFront(new OneSideWallStrategy(new Point2DDouble(x0,y0), new Point2DDouble(sx, sy), wallColor));
    wallSet.insertFront(new OneSideWallStrategy(new Point2DDouble(x0+sx,y0+sy), new Point2DDouble(wx, wy), wallColor));
    wallSet.insertFront(new OneSideWallStrategy(new Point2DDouble(x0+sx+wx, y0+sy+wy), new Point2DDouble(-sx, -sy), wallColor));
    wallSet.insertFront(new OneSideWallStrategy(new Point2DDouble(x0+wx,y0+wy), new Point2DDouble(-wx, -wy), wallColor));
  }

  public void updateState(Ball context) {
    wallSet.execute(updateAlgo, context);
  }
  
  public void init(Ball context) {
    wallSet.execute(initAlgo, context);
    context.setPaintStrategy(paintStrategy);
  }
  

}
