package ballwar.model.strategy;
import java.awt.*;
import util.*;

import ballwar.model.*;

/**
 * An ANoOpStrategy-based strategy that increments an associated player's score at every collision 
 * and resets that player's score if it is killed.   Note that more than one ScoreStrategy can be associated
 * with any given player.
 */
public class ScoreStrategy extends ANoOpStrategy {

  /**
	 * Associates this strategy with the currently selected player
	 * @param context This strategy's context.
	 */
	public void init(Ball context) {
    _player = context.getEnv().getSelectedPlayer();
  }

  /**
	 * The IPlayer associated with this scoring strategy.
	 */
	private IPlayer _player = IPlayer.NullPlayer;
  /**
	 * Adds one to the associated player's score.
	 * @param context This strategy's context.
	 * @param target The ball the context collided with.
	 */
	public void updateCollision(Ball context, Ball target) {
    _player.setScore(1+_player.getScore());
  }
  /**
	 * Sets the player's score to zero.   Does not kill the context ball.
	 * @param context This strategy's context.
	 */
	public void kill(Ball context) {
    _player.setScore(0);
  }
  
}