  package ballwar.model.strategy;

import ballwar.model.*;


/**
 * A Decorator design pattern strategy that decorates an IUpdateStrategy, enabling the 
 * strategy (the decoree) to be switched at run-time.   All methods, except setStrategy() are delegated
 * to the decoree.
 */
public class SwitcherStrategy implements IUpdateStrategy {
  
  private IUpdateStrategy _strategy = new StraightStrategy();
  
  /**
  * Initializes the context using the decoree strategy.
  * @param context The context for this and the decoree strategy. 
  */
 public void init(Ball context) {
    _strategy.init(context);
  }

  /**
  * Updates the state of the context using the decoree.
  * @param context The context for this and the decoree strategy. 
  */
 public void updateState(Ball context) {
    _strategy.updateState(context);
  }
  
  /**
  * Processes the collision using the decoree.
  * @param context The context for this and the decoree strategy. 
  * @param target The ball that the context with which the context has collided.
  */
 public void updateCollision(Ball context, Ball target) {
    _strategy.updateCollision(context, target);
  }
  
  /**
  * Process the context's kill request using the decoree.
  * @param context The context for this and the decoree strategy. 
  */
 public void kill(Ball context) {
    _strategy.kill(context);
  }
  
  /**
  * Sets the decoree to reference the given strategy.
  * @param newStrategy The new decoree.
  */
 public void setStrategy(IUpdateStrategy newStrategy) {
    _strategy = newStrategy;
  }  
}

