package ballwar.model.strategy;

import ballwar.model.*;
import lrs.*;
import java.util.*;

public class UpdateStrategySet implements IUpdateStrategy {
  private LRStruct _strategySet = new LRStruct();
  
  private IAlgo _updateAlgo = new IAlgo() {
    public Object emptyCase(LRStruct host, Object... context) {
      return null;
    }
    
    public Object nonEmptyCase(LRStruct host, Object... context) {
      ((IUpdateStrategy) host.getFirst()).updateState((Ball) context[0]);
      return host.getRest().execute(this, context);
    }
  };

  private IAlgo _collideAlgo = new IAlgo() {
    public Object emptyCase(LRStruct host, Object... context) {
      return null;
    }
    
    public Object nonEmptyCase(LRStruct host, Object... context) {
      ((IUpdateStrategy) host.getFirst()).updateCollision((Ball) context[0], (Ball) context[1]);
      return host.getRest().execute(this, context);
    }
  };
 
  private IAlgo _initAlgo = new IAlgo() {
    public Object emptyCase(LRStruct host, Object... context) {
      return null;
    }
    
    public Object nonEmptyCase(LRStruct host, Object... context) {
      ((IUpdateStrategy) host.getFirst()).init((Ball) context[0]);
      return host.getRest().execute(this, context);
    }
  };

  private IAlgo _killAlgo = new IAlgo() {
    public Object emptyCase(LRStruct host, Object... context) {
      return null;
    }
    
    public Object nonEmptyCase(LRStruct host, Object... context) {
      ((IUpdateStrategy) host.getFirst()).kill((Ball) context[0]);
      return host.getRest().execute(this, context);
    }
  };

  private IAlgo _remStrategyAlgo = new IAlgo() {
    public Object emptyCase(LRStruct host, Object... strategy) {
      return null;
    }
    
    public Object nonEmptyCase(LRStruct host, Object... strategy) {
      if(host.getFirst().equals(strategy[0])) {
        return host.removeFront();
      }
      else {
        return host.getRest().execute(this, strategy);
      }
    }
  };
  
  public void addCmd(IUpdateStrategy strategy) {
    _strategySet.insertFront(strategy);
  }
  
  public IUpdateStrategy removeCmd(IUpdateStrategy strategy) {
    return (IUpdateStrategy) _strategySet.execute(_remStrategyAlgo, strategy);
  }
  
  public void clear() {
    _strategySet = new LRStruct();
  }
  
  
  public void updateState(Ball context){
    _strategySet.execute(_updateAlgo, context);
  }

 public void updateCollision(Ball context, Ball target){
    _strategySet.execute(_collideAlgo, context, target);
  }

 public void init(Ball context){
    _strategySet.execute(_initAlgo, context);
  }

 public void kill(Ball context){
    _strategySet.execute(_killAlgo, context);
  }
  
}