package ballwar.view;
import javax.swing.*;
import java.awt.*;
import java.awt.event.*;

/**
 * An abstract configuration dialog box.
 * Takes a configuration panel and displays it.
 * Can be set to be either modal or non-modal.
 */
public abstract class AConfigDlg extends JDialog {
  JButton _okBtn = new JButton("Ok");
  JButton _acceptBtn = new JButton("Accept");
  JButton _cancelBtn = new JButton("Cancel");

  private static JPanel _nullPnl = new JPanel() {
    {
      add(new JLabel("No configuration available"));
    }
    public String toString() {
      return "Null Panel";
    }
  };
  
  public AConfigDlg(JFrame owner, IConfigAdapter configAdpt, Object fac, boolean isModal){
    super(owner, isModal);
    
    JPanel configPnl = configAdpt.getConfigPanel(fac, _acceptBtn, _cancelBtn);
    
    if(null == configPnl) {
      setTitle(_nullPnl.toString());
      configPnl = _nullPnl;
    }
    else {
      setTitle(configPnl.toString());
      init(configPnl);
    }
    setVisible(true);
  }

  public AConfigDlg(JFrame owner, IConfigAdapter configAdpt, Object fac){
    this(owner, configAdpt, fac, false);
  }

  /**
   * Private method to initialize the GUI components
   * @param configPnl  The externally supplied configuration 
   * panel to show.
   */
  private void init(JPanel configPnl) {
    
    
    _okBtn.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e){
        okBtnClick(e);
      }
    });
    


    _cancelBtn.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e){
        cancelBtnClick(e);
      }
    });
    
    JPanel btnPnl = new JPanel();
    btnPnl.add(_okBtn);
    btnPnl.add(_acceptBtn);
    btnPnl.add(_cancelBtn);
    
    getContentPane().add(configPnl, BorderLayout.CENTER);
    getContentPane().add(btnPnl, BorderLayout.SOUTH);
    
    pack();
  }
  
  /**
   * Protected methods to process the clicking of the
   * OK button.  Default behavior is click the Accept button
   * and then close the window.  
   * Override this method to provide custom
   * behavior.
   * @param e ActionEvent from the clicking of the button
   */
  protected void okBtnClick(ActionEvent e) {
    _acceptBtn.doClick();
    setVisible(false);
  }


  
  /**
   * Protected methods to process the clicking of the
   * Cancel button.  Default behavior is to simply close the 
   * window.  Override this method to provide custom
   * behavior.
   * @param e ActionEvent from the clicking of the button
   */
  protected void cancelBtnClick(ActionEvent e) {
    setVisible(false);
  }

}