
package ballwar.view;
import java.awt.*;

/**
 * Interface to the model from the view that is used to control the balls once they are already created.
 */
public interface IBallCtrlAdapter {
 /**
	 * Requests that the model have all the balls paint themselves onto the given Graphics 
	 * context and to update ther states.
	 * @param g The Graphics context onto which the balls should paint themeselves.
	 */
	public abstract void paint(Graphics g);

 /**
	 * Asks the model to clear (delete) all the balls.
	 */
	public abstract void clearBalls();

	/**
	 * Tells the model to switch the decoree strategy in the currently defined SwitcherStrategy to 
	 * a new strategy, as specified by the given factory. 
	 * @param fac The factory for the model to use to create the new decoree strategy for SwitcherStrategy..
	 */
	public abstract void switchStrategy(Object fac);

	/**
	 * Asks that the models augment or replace the current given display string.
	 * @param origStr The original display string.
	 * @return The new display string.
	 */
	public abstract String getDisplayStr(String origStr);
}

