package util;
import java.awt.geom.*;

public class Point2DDouble extends Point2D.Double {
  
  public Point2DDouble() {
    super();
  }
  
  public Point2DDouble(double x, double y) {
    super(x,y);
  }
  
  public Point2DDouble(Point2DDouble pt) {
    super(pt.x,pt.y);
  }
  
  public void translate(double x, double y){
    setLocation(this.x+x, this.y+y);
  }
  
  public void translate(Point2DDouble delta){
    translate(delta.x, delta.y);
  }
  
  public void setLocation(Point2DDouble pt) {
    setLocation(pt.x, pt.y);
  }
  
  public void multBy(double a) {
    x *= a;
    y *= a;
  }
  
  /**
   * Returns a unit vector in the direction from this pt to the given pt
   */
  public Point2DDouble unitVecTo(Point2DDouble pt) {
    Point2DDouble v = vecTo(pt);
    double r = distance(pt); // length of difference
    v.multBy(1.0/r); // normalized
    return v;
  }
  
  /**
   * Returns a vector pointing from this point to the given pt.
   */
  public Point2DDouble vecTo(Point2DDouble pt) {
    Point2DDouble v = new Point2DDouble(this);
    v.multBy(-1.0); 
    v.translate(pt); // difference in vectors
    return v;
  }
  
  /**
   * Returns the length of the vector from the origin to this point.
   */
  public double getLength(){
    return Math.sqrt(x*x+y*y);
  }
  
  /**
   * Returns a unit vector in the direction of this vector
   */
  public Point2DDouble getUnitVec() {
    double r = getLength();
    return new Point2DDouble(x/r, y/r);
  }
  
  /**
   * Inner (dot) product between this vector and the given vector
   */
  public double innerProd(Point2DDouble pt) {
    return x*pt.x+y*pt.y;
  }
  
  /**
   * Scalar value of the cross product between this vector and the given vector
   */
  public double crossProd(Point2DDouble pt) {
    return x*pt.y - y*pt.x;
  }
}