package util;

import java.awt.*;

/**
 * Utility class that supplies  class routines for generating various random values
 */
public class Randomizer implements IRandomizer {
  public static Randomizer Singleton = new Randomizer();
  
  private Randomizer() {
  }
  
  /**
   * Generates a random location Point2DDouble subject to the constraint that 0<=X<=maxX and 0<=Y<=maxY.
   */
  public Point2DDouble randomLoc( Rectangle rect)
  {
    return (new Point2DDouble( randomInt(0, rect.width), randomInt(0, rect.height)));
  }
  
  
  /**
   * Generates a random location Point2DDouble subject to the constraint that 0<=X<=maxX and 0<=Y<=maxY.
   */
  public Point2DDouble randomLoc( Dimension dim)
  {
    return (new Point2DDouble( randomInt(0, dim.width), randomInt(0, dim.height)));
  }
  
  /**
   * Returns a random integer greater than or equal to min and less than or equal to max.
   */
  public int randomInt(int min, int max)
  {
    return (int)Math.floor((Math.random()*(1+max-min))+min);
  }
  
  /**
   * Returns a random double greater than or equal to min and less than or equal to max.
   */
  public double randomDouble(double min, double max)
  {
    return (Math.random()*(max-min))+min;
  }
  
  /**
   * Returns a random velocity (as a Point2DDouble) subject to the constraint that the absolute value of the vleocity (speed) is less than maxV.
   */
  public Point2DDouble randomVel( Point2DDouble minVel, Point2DDouble maxVel)
  {
    return (new Point2DDouble (randomDouble(minVel.x, maxVel.x), randomDouble(minVel.y, maxVel.y)));
  }
  
  /**
   * Returns a random square Dimension, whose width is maxDim.width/2<=width<=maxDim.width
   */
  public Dimension randomDim( Dimension maxDim)
  {
    int x =  randomInt(maxDim.width/2,maxDim.width);
    return new Dimension(x,x);
  }
  
  /**
   * Generates a randomly located and sized rectangle
   */
  public Rectangle randomBounds( Rectangle rect, Dimension maxDim)
  {
     
    return new Rectangle(randomInt(0, rect.width), randomInt(0, rect.height),
                         randomInt(0, maxDim.width), randomInt(0, maxDim.height));
  }
  
  /**
   * Generates a random color
   */
  public Color randomColor()
  {
    return new Color( randomInt(0,255),randomInt(0,255),randomInt(0,255));
  }
  
  /**
   * Returns a random choice of one of two objects, x and y, where probX is the probability 
   * that x will be picked (0<=x<=1).
   */
  public Object randomChoice(Object x, Object y, double probX) {
    return (Math.random()<probX) ? x: y;
    
  }

}

